{{extend defaultLayout}} {{block 'css'}}
<script src="{{_res_path}}template/extend/js/qrcode.min.js"></script>
<link rel="stylesheet" type="text/css" href="{{_res_path}}template/bilibili/css/dynamic/DYNAMIC_TYPE_DRAW.css" />
{{/block}} {{block 'main'}}
<div class="spacer1"></div>

<div class="userinfo">
  <img src="{{avatar_url}}" alt="头像" class="avatar" />
  <img src="{{frame}}" class="avatar-1" />
  <div class="name_and_followers">
    <div class="username"><span>{{@username}}</span></div>
    <div class="dynamic_create_time">{{create_time}}</div>
  </div>
  <div class="bili_dyn_item_ornament">{{@decoration_card}}</div>
</div>
<div class="spacer1"></div>
<div class="info">
  <div class="info_text">{{@text}}</div>
  <div class="spacer4"></div>
</div>
{{each image_url val}}
<div class="cover">
  <div class="imgbox">
    <img class="imgbox_1" src="{{val.image_src}}" alt="封面" />
  </div>
</div>
<div style="height: 70px"></div>
{{/each}}
<div class="info">
  <div class="work_status">{{dianzan}}点赞 · {{pinglun}}评论 · {{share}}分享</div>
  <div class="work_status">图片生成时间: {{render_time}}</div>
  <div class="spacer5"></div>
</div>
<div style="height: 90px"></div>
<div class="under">
  <div class="rectangular_box">
    <div class="user" style="align-items: center">
      <div class="bitop">
        <img src="{{_res_path}}image/bilibili/bilibili-light.png" />
        <br>
        <span class="userinfo_text" style="font-size: 50px;">长按识别二维码即可查看全文</span>
      </div>
      <div class="userinfo_text">
        <span>UID: {{user_shortid}}</span>
        <span>获赞: {{total_favorited}}</span>
        <span>关注: {{following_count}}</span>
        <span>粉丝: {{fans}}</span>
      </div>
    </div>
    <div class="qrcode_box">
      <div class="qrcode_text">{{dynamicTYPE}}</div>
      <div id="qrcode"></div>
    </div>
  </div>
</div>
<script>
  qrcode = new QRCode(document.getElementById('qrcode'), {
    width: 600,
    height: 600,
    colorDark: '{{useDarkTheme}}' === 'true' ? '#c3c3c3' : '#3a3a3a',
    colorLight: '{{useDarkTheme}}' === 'true' ? '#121212' : '#f4f4f4',
  })
  qrcode.makeCode('{{share_url}}')
</script>
{{/block}}