jsonp_callback("<!doctype html>\n<html lang=\"zh-cn\">\n  <head>\n    <meta charset=\"utf-8\" />\n    <meta name=\"viewport\" content=\"width=device-width\" />\n    <link href=\"#\" rel=\"shortcut icon\" />\n    <link href=\"{{_res_path}}template/extend/css/common.css\" rel=\"stylesheet\" type=\"text/css\" />\n    <link href=\"{{_res_path}}font/font.css\" type=\"text/css\" rel=\"stylesheet\">\n    <link href=\"https://fonts.googleapis.com\" rel=\"preconnect\">\n    <link href=\"https://fonts.gstatic.com\" rel=\"preconnect\" crossorigin>\n    <link href=\"https://fonts.googleapis.com/css2?family=Noto+Sans+KR:wght@400;700&display=swap\" rel=\"stylesheet\">\n    <link href=\"https://gfonts.aby.pub/css2?family=Noto+Sans+KR:wght@400;700&display=swap\" rel=\"stylesheet\">\n    <link href=\"https://fonts.font.im/css2?family=Noto+Sans+KR:wght@400;700&display=swap\" rel=\"stylesheet\">\n  \n    <link\n      href=\"https://fonts.googleapis.com/css2?family=Libre+Barcode+128&family=Noto+Color+Emoji&family=Noto+Emoji:wght@300..700&display=swap\"\n      rel=\"stylesheet\">\n    <link\n      href=\"https://fonts.font.im/css2?family=Libre+Barcode+128&family=Noto+Color+Emoji&family=Noto+Emoji:wght@300..700&display=swap\"\n      rel=\"stylesheet\">\n    <title>kkkkkk-10086</title>\n    {{block 'css'}} {{/block}}\n  </head>\n\n  <body {{@sys.scale}}>\n    <div class=\"container\" id=\"container\">\n      {{block 'main'}}{{/block}}\n      <div class=\"copyright\">{{@copyright}}</div>\n      <script>\n        // 获取当前时间并自动设置主题\n        function setThemeBasedOnTime () {\n          const body = document.body\n          console.log('{{useDarkTheme}}' === 'true' ? '深色模式' : '浅色模式')\n          if ('{{useDarkTheme}}' === 'true') {\n            body.classList.remove('light-mode')\n            body.classList.add('dark-mode')\n          } else {\n            body.classList.remove('dark-mode')\n            body.classList.add('light-mode')\n          }\n        }\n  \n        // 页面加载时调用函数自动设置主题\n        window.onload = function () {\n          setThemeBasedOnTime()\n        }\n      </script>\n    </div>\n  </body>\n</html>\n")